@@ -1,6 +1,3 @@
-mod rceq;
-pub use rceq::{RcEq};
-
 #[macro_use]
 mod array_map;
 pub use array_map::{ArrayMap, AsUsize};
@@ -13,9 +10,3 @@ pub use comma_separated::{CommaSeparated};
 
 mod rotate;
 pub use rotate::{rotate_left, rotate_right};
-
-mod permutation;
-pub use permutation::{permutation};
-
-mod and_or;
-pub use and_or::{AndOr};
